@@ -64,7 +64,7 @@ class Github(object):
 		if self.usersRemote is None:
 			# if there is no official repository, create a users repository from scratch!
 			if self.officialRemote is None:
-				self.createRepository(repositoryName=self.repositoryName, options=options)
+				self.usersRemote = self.createRepository(repositoryName=self.repositoryName, options=options)
 			# else, fork the repository!
 			else:
 				self.usersRemote = self.officialRemote.fork()
@@ -124,7 +124,7 @@ class Github(object):
 
 		if response.status_code == 429:
 			raise GithubRateLimit(username=self.username)
-		elif response.status_code != 200:
+		elif response.status_code not in [200, 201]:
 			raise GithubCreateFailed(repositoryName=repositoryName, statusCode=response.status_code)
 		else:
 			return Remote(url=self.usersUrl, apiAuth=self.auth)
